
# q-expansion of newform 324.8.a.c, downloaded from the LMFDB on 09 June 2024.

# We generate the q-expansion using the Hecke eigenvalues a_p at the primes.
# Each a_p is given as a linear combination
# of the following basis for the coefficient ring.

def make_data():

    from sage.all import prod, floor, prime_powers, gcd, QQ, primes_first_n, next_prime, RR

    def discrete_log(elts, gens, mod):
        # algorithm 2.2, page 16 of https://arxiv.org/abs/0903.2785
        def table_gens(gens, mod):
            T = [1]
            n = len(gens)
            r = [None]*n
            s = [None]*n
            for i in range(n):
                beta = gens[i]
                r[i] = 1
                N = len(T)
                while beta not in T:
                    for Tj in T[:N]:
                        T.append((beta*Tj) % mod)
                    beta = (beta*gens[i]) % mod
                    r[i] += 1
                s[i] = T.index(beta)
            return T, r, s
        T, r, s = table_gens(gens, mod)
        n = len(gens)
        N = [ prod(r[:j]) for j in range(n) ]
        Z = lambda s: [ (floor(s/N[j]) % r[j]) for j in range(n)]
        return [Z(T.index(elt % mod)) for elt in elts]
    def extend_multiplicatively(an):
        for pp in prime_powers(len(an)-1):
            for k in range(1, (len(an) - 1)//pp + 1):
                if gcd(k, pp) == 1:
                    an[pp*k] = an[pp]*an[k]
    from sage.all import PolynomialRing, NumberField, ZZ
    R = PolynomialRing(QQ, "x")
    f = R(poly_data)
    K = NumberField(f, "a")
    betas = [K([c/ZZ(den) for c in num]) for num, den in basis_data]
    convert_elt_to_field = lambda elt: sum(c*beta for c, beta in zip(elt, betas))
    # convert aps to K elements
    primes = primes_first_n(len(aps_data))
    good_primes = [p for p in primes if not p.divides(level)]
    aps = map(convert_elt_to_field, aps_data)
    if not hecke_ring_character_values:
        # trivial character
        char_values = dict(zip(good_primes, [1]*len(good_primes)))
    else:
        gens = [elt[0] for elt in hecke_ring_character_values]
        gens_values = [convert_elt_to_field(elt[1]) for elt in hecke_ring_character_values]
        char_values = dict([(
            p,prod(g**k for g, k in zip(gens_values, elt)))
            for p, elt in zip(good_primes, discrete_log(good_primes, gens, level))
            ])
    an_list_bound = next_prime(primes[-1])
    an = [0]*an_list_bound
    an[1] = 1
    
    from sage.all import PowerSeriesRing
    PS = PowerSeriesRing(K, "q")
    for p, ap in zip(primes, aps):
        if p.divides(level):
            euler_factor = [1, -ap]
        else:
            euler_factor = [1, -ap, p**(weight - 1) * char_values[p]]
        k = RR(an_list_bound).log(p).floor() + 1
        foo = (1/PS(euler_factor)).padded_list(k)
        for i in range(1, k):
            an[p**i] = foo[i]
    extend_multiplicatively(an)
    return PS(an)
level = 324
weight = 8
poly_data = [373225328, -56851263, -2291461, 496633, 4994, -1289, -3, 1]

# The entries in the following list give a basis for the
# coefficient ring in terms of a root of the defining polynomial above.
# Each line consists of the coefficients of the numerator, and a denominator.
basis_data  = [[[1, 0, 0, 0, 0, 0, 0], 1], [[960757498036, -76410780887, -7371057328, 358758001, 16746767, -375026, -12407], 228604194], [[598479021772, -91662719945, -157810180, 421767655, -9274075, -406034, 11395], 32657742], [[11442148060819, -1606071633677, -1149202036, 7395255553, -196374937, -7082210, 243601], 114302097], [[22521727355330, -3570426623911, 1519294288, 16267932821, -418533653, -15422698, 524141], 228604194], [[-1270904432, 761696677, -55638172, -3751475, 267503, 3634, -263], 72366], [[-1265838812, 749973385, -55638172, -3751475, 267503, 3634, -263], 72366]]

hecke_ring_character_values = None
aps_data = [[0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0], [-46, -1, 0, 0, 0, 0, 0], [12, 0, -1, 0, 0, 0, 0], [16, 2, 2, -1, 0, 0, 0], [264, 4, 0, 1, -1, 0, 0], [-8, -2, 11, 2, 3, 0, -1], [1452, 38, -4, 5, 4, -1, 2], [-2739, 4, 49, 1, -6, 3, 5], [-884, 2, 60, 3, -3, -24, 4], [21915, 424, 11, -11, 2, -35, 7], [10062, 815, 54, -55, -35, 28, 70], [-63767, -7, -238, -7, 63, 6, 120], [55047, 444, -12, 66, 24, 125, -169], [-42722, -144, -293, 34, 36, -258, 54], [-64560, -91, -780, -39, 39, 312, -376], [-374249, 208, 116, -10, -240, 183, 371], [20984, -1360, 46, -187, -119, 520, -554], [-235108, -5898, 198, -57, -348, -486, 144], [-621963, 88, 1694, 449, 162, 309, -555], [-305014, -2342, 623, -428, 113, 8, 551], [-344235, -9124, -643, -85, 310, 11, -283], [-1848505, 942, 4264, 13, 372, -126, 209], [-2811972, 883, 224, -1201, -549, 210, 366], [408615, 15097, 2916, 1243, -433, -558, 1350], [-5442358, -8891, -5068, 1442, -210, 1848, -944], [-354568, 680, -4379, 80, 100, 2464, 256], [-7356880, -5278, -30, 393, -108, -3435, 3162], [2378652, 34913, -5576, 689, -41, -1548, -1512], [-7753301, 5463, -11497, 1367, -732, -1782, -1727], [1494372, -2916, 10764, -1314, 2484, 626, -6436], [-16230937, -27754, -1770, 1029, -396, 1650, -6831], [-20129573, 13151, -3548, -3011, 921, 3282, -3910], [-3723933, -40904, 15670, -2036, 1208, 4151, 2615], [-30008552, 20830, 20184, -6213, -603, -3948, 5136], [-3361957, -81748, 32521, 1991, -3350, -4961, 463], [1770234, -21475, -37784, -1150, 610, -4872, -5016], [-6250182, -132316, -39246, -3874, -5936, 9964, -3602], [-36130292, 73632, 3085, 7498, 6192, 7218, -2136], [-39460626, 94665, 43746, 870, 2520, -15360, -6426], [-34846078, 144932, -13980, 1878, -7164, 1542, -13350], [-7899378, -18155, 56620, 175, -247, -6868, 26732], [-49751302, 61408, -34339, -9730, -6564, -15168, 17530], [6544367, 35413, 73664, -3713, -6997, -20698, -12082], [-64102884, -110978, 14116, 2188, 10632, 32844, -24916], [751767, 71688, 10126, 3225, 10374, 16669, -1793], [2098206, 113708, -102376, -5746, -9500, -10879, 23252], [22662714, 350540, -72947, -9430, -5420, -20292, -1770], [-22882922, 339630, -55642, 5525, 9420, 762, 24406], [14078598, 130657, 35918, -9998, 10880, -9584, -21638], [-31870064, 566771, 19607, -15271, -12474, 31578, 2661], [-23997217, -532644, -36753, -4725, 4902, 22599, -45725], [-11099649, -77526, -94018, 37602, -6984, 18072, 15030], [1822080, -347974, 77798, 17123, -34032, -57021, 38806], [-3469463, 49878, -20774, 34372, 27738, -56820, 3594], [7496435, -782780, 152207, -22345, 3570, 61857, 19951], [-22291598, -486481, 125614, -20927, -17835, -6420, 46370], [26954036, 173628, -173514, 4500, 17424, 17094, -88368], [-35393082, -678505, -46718, -22240, -27710, -9264, 52638], [89525237, 723374, -86177, 8350, -13053, 69612, -49589], [-28164591, -257134, 89650, -80821, -22184, 86892, 15387], [45793224, -1132253, 123100, -8582, -8718, -23028, -20392], [-13119784, -531238, 36010, 10943, 32032, -365, -56474], [327760233, -55540, -24749, 85693, -23598, 23949, -50535], [-51460311, -757814, 17548, -18656, 13616, 6572, 37256], [112392262, -1215416, -41246, -100349, -25401, 7596, -5186], [30532542, -368300, -112812, 83614, 40316, 7587, -45360], [29006637, -154354, -91950, 90584, 2206, -34484, -28646], [434695354, -1547970, 39810, 15045, 65820, -24288, 103406], [11104716, 265817, -27222, 109112, 78826, 39040, -131774], [284698573, 249437, -315204, 91593, 66957, -108846, 3322], [593262032, -741984, -47690, -67826, -62880, 176844, -149632], [92573057, 1685196, -139533, -1521, -164934, 230301, -165555], [86366004, 1543218, 392212, -185133, -20427, -192008, 135040], [-148852347, -523352, 382888, -38624, -133168, 5138, 210323], [711795554, 1551416, 693119, 32384, 68196, -58026, 232874], [200397282, 1020391, 217570, 4384, 144282, -246648, 181106], [104836200, 621349, -458032, -38579, 174299, 129172, 14428], [10992293, -1618489, 121294, -25829, -115851, 107814, -3608], [-126692775, 411546, -205432, -182112, -100092, 55764, 16236], [648599566, -240612, -718438, -132562, -55416, -129765, 212464], [51101694, -282676, -1227552, -3745, -1799, -189572, -133208], [676987976, -206588, -345546, 172110, 55236, 118296, -33712], [-99126162, -396564, 1238721, -9006, 7341, 5612, -225739], [58972727, -1758556, 115297, 113177, 76138, 110005, 93523], [691828839, 894612, -289766, -8282, 139452, 74367, -215765], [-553673782, 299772, -1687547, 114862, -137859, -347820, 405641], [-335009535, -581791, 616942, -77239, -197081, -356070, 505680], [-924400780, -84646, 689132, 126767, -55779, 112932, 438380], [-284885193, -1212348, -1317455, -182487, 59142, 262231, -268565], [303869176, 519578, -741168, -359553, 120948, 17937, 347818], [406498953, -782928, -2465767, 516977, 336090, 249501, -321583], [-210249864, 218256, 930502, 1554, 38856, -428336, -19424], [158791495, -865196, -370580, -81104, 83112, -192291, -82025], [57940721, -3734892, -83610, -502128, -82584, 447531, -397047], [-167280617, -3932316, 719038, 161311, -196506, 49887, 335115], [-1715832942, 2344556, -227600, -41981, 225837, 378612, -631164], [-2252620842, 2715757, 1354771, -92999, -27114, -493662, 482597], [-293116915, -3281162, 1096700, -249893, 136988, -349741, 104213], [-380158284, 2953762, 1025728, 350932, 241592, 809144, -405160], [552325394, -1042746, -420600, -696669, -494436, 479106, 40410], [-3309539772, -6115217, 206546, 291647, 585243, -295584, -384042], [-158498484, 8427210, 2675954, 110495, -344400, -26190, 427136], [-3386890975, -2728034, -2962436, 234556, 388188, 65700, -472152], [-1140951642, -5128670, -1961408, 394231, -221584, -693724, 276938], [-377478940, -3269428, -2451479, 331268, 461227, -827144, 465325], [104327795, 7508512, 235144, -251942, -724428, -208035, -319341], [-3691511346, 3756889, 645502, -550709, -112551, 801294, -123604], [-488825684, -5631044, -3176655, -1013586, 97884, 17910, 692304], [953325303, -7294691, 1150970, 421591, 119561, 699130, -553304], [864918462, 1674040, 26737, 225820, 796220, -753424, -188986], [619536380, -10198319, 1917920, 217909, -496189, 1012028, 593036], [-3648129599, 8443487, -2499524, 202543, 357627, -1249854, 1002374], [-1677385120, -11845006, -55778, 396797, -74156, 551194, -655988], [-543916356, 4021868, 3599622, -1066252, -685004, 1274098, 202132], [-2822394977, 18531230, -58782, -530106, 518712, -553464, -472406], [625100504, -10735578, -805626, 785133, 572832, -822888, 310680], [1848871248, 13318812, 145538, -30322, -415788, 336588, -157912], [-4478265364, -12115751, -315448, -603364, -563376, 941220, 663424], [995184516, -5997896, -1398174, 392364, -755364, 87111, 264298], [141463856, -14125735, 153730, -764260, -348338, -1866872, 1620238], [-2892697227, -9726960, -2095325, -521040, 37245, 764080, 988087], [-3123403602, -2744759, -2164980, 523254, -634494, -456960, -18932], [2684190756, 4775934, 3387094, 518101, 730824, -1148199, 500110], [-399595389, -4949862, 7694898, -619359, -1303572, -749188, -358063], [-1984896974, -2317783, 89864, 282335, 825741, -658764, -1430352], [3323659296, 3407191, 457062, -671630, 424256, -46800, -180054], [3811805784, -19750968, 298220, -1394752, 131988, -1800000, 1820228], [-2928923833, 13159956, -3247977, 468759, 293046, -1958715, 2369223], [-4513373766, -5467486, 6967414, 878921, 598789, -280632, 353022], [-280396377, 458900, 3912136, 658478, 421576, 57960, -2387259], [6849336340, -15030564, -435479, 265444, 477396, 607488, -2687856], [2687221422, 20702976, -2177437, -1511292, -495564, 956286, 2074878], [-2876466550, 11280388, -487216, -1947608, -1043632, 112544, -626560], [-298570623, -14425794, 2477719, 500626, 2180751, -2622588, 286315], [3554847069, 6916653, -292559, 1468395, 677718, 3357430, -4346717], [1303263078, 2957637, -1258060, -828337, -1237443, -95904, -358936], [-6743733085, -7678150, 1940602, -2311735, 65920, 2850238, -541739], [2543960106, 18019380, -6555148, 425855, 670845, -868476, 703220], [299964282, -14584940, -1543471, -1231138, -223587, 1597176, 3088665], [-5529755412, -10211910, -6902256, -111453, -350940, 3114149, -1929682], [884971390, -19642274, -5397854, 516397, 344013, -4652808, 4050802], [1918167429, -27259688, -266775, -282677, -1534558, 645345, 809433], [8193090094, -8711528, -8623868, 1094998, -887088, -1168110, 1816894], [5976194496, -23744481, 3296614, 216003, 1625631, 750364, 1023934], [11232356192, 5125308, -8380939, -1391470, -840564, 254292, -193980], [-488289586, -8409386, -5352790, 2098201, -1582411, 2396252, -4122670], [4077709423, 1062924, 5883689, 718826, 1182129, 2349516, -5824847], [3447506862, -43098890, 5498254, 2018467, 387296, -790702, -441058], [12052468648, 6838300, 499474, 2556280, 2032620, 227154, -1328696], [5160510042, 2869548, 5282768, -1688853, -2518827, -2495172, 250620], [4141701940, 34170383, 9629612, 1196123, 1833759, 2704230, -2751066], [9111890268, -25360374, -909152, 364119, 1026156, 978553, 1165822], [8845205169, -14727772, -4061021, 948787, 963378, -2592897, 3021441], [-2956011561, -30432332, -1735080, 1647652, 3424028, 1430187, 62619], [5386740945, -48989640, 2398175, 492155, -1879782, -5437563, 5334497], [-11575545700, -12559264, 933466, -1605658, 1759036, -1765796, 3435184], [1518677161, -5883312, 8970891, -958500, -3272739, 2680692, -5619805], [14910640518, 14710213, 430858, -263513, -3877387, -6368902, 3393644], [-4411834784, -52678973, -6343526, 672730, -1284960, 10469172, -951566], [2323690434, -2155878, 1821758, 4064243, 4140372, -824268, -4283338], [-1761439874, -14481984, -1601959, -3594106, -2265159, 802500, 2563573], [9752308145, -3510524, 19519511, -1776911, 3766226, 1449149, -3981871], [-1056258233, 18850902, -7826376, -5599035, -3032376, 2699853, -5307625], [-436495671, 38134480, -9704304, -4084770, -3286830, -6285516, -239456], [5593645479, 68918476, -11017443, -1001931, -2514594, 866457, -1447217], [17569087928, -32132880, -23678070, 1294200, 905220, 4134930, -557940], [-15875065546, 7009241, 2392408, 2597894, 4896946, -5524460, 2537476], [-1331288326, 35124845, -6730118, -708589, 3758689, -5026982, -4621580], [-1861721210, 45433214, -24480716, 1789561, 2820819, 3544944, -4077424], [-15050591993, -106308040, -6319168, -2718604, 1562256, 5295111, -5019837], [10529612282, 10284068, 11974324, 2235479, -3447167, -5081192, 12182344], [-4921530779, 49232660, -16608125, 5089135, -566610, 3378135, -235135], [18981340977, -30748233, 7304000, 395223, 1766667, -6260706, 9379710], [9059662842, -69631236, 1656517, 7293942, -441972, 6699850, -5532602], [-11614265355, -111651509, -6691671, 2270121, 451788, -7123650, -4557857], [-18442612797, 32097928, 296684, 3190474, -2042524, -4527695, -1197869], [-8148766628, -11284149, -7129678, 3855995, 789459, -11440788, -4557662], [-6649095792, -18689608, -3321172, 454448, 5009092, -7161472, 1728308], [-7395429276, -73868199, -33621582, -5470692, -4208826, -5349472, 4030430], [24154447758, 3265052, 710553, -1336402, 1632232, 1351312, 11006518], [-21569725099, 92661400, 8194518, 2729424, 196896, -4697043, 3986945], [9101900222, -35453587, -3392414, -303778, 4107448, 2260072, 8892574], [-11097285436, 111373308, -1890419, -6306668, -3740397, -2614980, 15317117], [-12915951082, -15814468, 16111541, 2977778, -3976188, -4153170, -521758], [-12694402196, 23196130, 16580474, 1845107, -1384737, 4385196, 4811810], [-11722865578, -137278442, -17806390, 4656262, 56948, -206332, -7344274], [-4940569101, -8221254, 5283746, -4349031, 3860196, 814356, 2450385], [19586611995, -24434032, 16906394, -2806156, 1756918, 9676328, -6510466], [-17313981076, 12965404, -909508, 2768912, -2319456, -379476, -8840648], [34846739202, -63842050, -20004613, -9027160, -701255, -3779344, -718981], [-27875189108, 8523570, -30535558, 5129375, 483360, 142080, -843836], [-6810906072, 140531614, 32585230, -878459, -4905472, 9894353, 6144074], [-11333297096, 4943929, 14563978, -4019780, -5058282, -15480744, 18441730], [-35665983256, 20128630, 7833212, 2415035, -3848880, 10383069, 2214922], [-2089124989, -45158210, -40265704, -2426830, 8446110, -2352660, -488768], [17997996879, -12919605, 10235218, 3677709, -4546497, -11532350, 14261908], [-34628155956, 47657397, -19937582, -1823172, -449238, 4523908, -8133578], [2631761529, -17897342, -32791286, -6634688, 530418, 5410440, -13577914], [-9307394616, -16410488, -73184148, 7788138, 3471072, 12586098, -8982656], [5023534130, 51911811, 26355854, 5390576, -4095270, 3793788, 3011946], [3451280766, 69281908, -15281325, 2743042, -863464, 8551506, -19934682], [33340026720, -22817243, -38782734, 10647868, 5943362, -3904236, -7992810], [50846732309, 8075294, 2461102, -8972008, -3139958, 6110716, -1165706], [-36471060244, -98491426, -16879656, -768117, 5402592, 9262953, -1823562], [12795999558, -35698727, -8198696, 11908867, 8901813, 1798992, 2614772], [-16719136128, -36037680, -9004514, 5718828, 665232, -10462226, 10403200], [-28672684515, -65520220, -25828624, 2300870, -9501240, 608619, 10382653], [27523049957, 131169700, 5035066, 3838798, -2725092, 1414668, -1210026], [29229611007, 4954864, -11702318, 1218772, -509176, -18028021, 21889187], [-36179260440, 206933518, 9351907, 3175522, 5252483, -20131384, 12398399], [14748197934, -20407172, 40288950, -5765133, -279345, 16138992, 6522934], [61926766244, 49977836, 22825177, -6276976, -1623584, -1363610, -5056412], [-22865824882, 11386300, -37025500, 3034790, -4846260, 9877155, -17361488], [10025881512, 158480988, 11823285, -8834478, 2132280, -1394238, -285576], [-54940157317, -118358364, 1906674, -1642944, 3059742, 5685396, -18524046], [-69636651897, -62104712, 3226931, -6205463, -63622, 15107401, -11442197], [29315817729, -90228369, 13749786, -7479153, 1364445, -12602010, 20767020], [-3535069848, -253444024, -1844970, -7981986, -3241644, 2038776, 15849284], [60503431976, -23352722, 4414598, -3882553, 2695983, -1644732, -9986834], [-75100230534, 181869780, -5384690, 3813375, 3709383, -11115788, 10431442], [43018219088, -32498920, -96863789, -2140702, 5099164, 13643872, -8154752], [50344240181, -169774849, 7304346, -11522853, -10595331, -14597814, 4155456], [94195637352, 35466700, 40903838, 6676210, -6081220, -551228, -17608688], [941711901, 264466332, 27346946, 19140188, 6139992, -21709989, -5923531], [-69294533514, 122267451, 9606898, 10057728, 4179390, -13045868, 23990614], [76504422571, -40604775, -57691681, 10320305, 6527310, 7505826, -15774899], [25152177228, -39600220, 36512842, -1820864, -7688484, -24433494, 28723068], [-23890978533, -193913108, 98872981, -2524997, -6607258, -2675125, 25202243], [-25033055942, 93612152, -74689582, 10521722, -13121676, 1331697, 24084408], [51701021778, -105684977, -12093518, -18297428, -10151842, 24504152, -17137774], [-73579420734, -161574228, -12522834, 2936646, 5817384, 1731920, -24564826], [31783210815, 4363568, -43645673, 1043183, 3881374, 129915, 44971119], [65875191657, 183050372, -48026218, -5816206, -11789328, 29572488, -10534682], [-82304638842, 111261236, 7717938, -23747086, -6821864, -10224851, 17599492], [30562010650, 91602572, 37463141, -7879402, -6633288, 39224508, -9022590], [-96691736637, 54181970, 50849, -5596108, -16653449, 11414888, -21015223], [81749661262, 187464933, -18883424, -14511293, -5931747, 12022896, 16432224], [-17579372385, -175297884, 19518844, -4856954, -5614716, 10743099, -38551733], [40287897360, 104049356, -73181044, 7206662, -2521812, -7481478, -21536288], [-5296292167, 159624424, 51252402, -19370064, -15049176, 7061433, 9856157], [107272335974, -9457676, 108644972, -680798, -3341572, 27502370, -11876362], [-110038448524, 58783380, 45306639, -16659930, -9294360, -615516, 13764036], [-13681639768, 337916155, 7571678, -3377501, -786889, -36678868, 27977810], [70939960837, 15673825, -30345504, -26323035, 5360445, -7582134, 22086726], [42788228364, 158650928, 3242855, 22262342, 17709900, -8574858, -8377076], [-73156475784, 360407852, 45187820, -21473152, -2719028, -20227528, 5276216], [-69108219140, -150855346, 12949076, 3607199, 12952512, 44903040, -10601388], [49372461708, -35503692, 2423508, -9821184, 16757844, 6189131, 3201386], [36455251740, -379970232, 68401882, 8274682, -11684172, -22591344, 1495384], [-115396092172, 107778248, 25979632, 24547277, 1259503, 17254420, -22768664], [32403133926, -58416258, -2567265, -10795452, 7767333, 26935020, -56566557], [20195804081, 103551712, 41904877, 82663, -2236698, -6591987, 10728177], [-15447149113, 88285033, 152056751, 16218565, 18267950, 34640798, -27973639], [69393324226, 229787973, -40798030, 26710802, 6977868, -2451192, -12577718], [-59022106723, 167166232, 105989556, -6209454, -11128020, 26316864, -17134777], [-87190304308, 90257077, -11156104, -16609259, -7591021, 19919780, 12271304], [102225630942, -81856908, 133264440, -8391762, -22882788, 3603335, 9089720], [9170896180, 124364562, -61865628, -2682732, -1591188, 47496288, 10194068], [-53657933088, -299903546, 84495407, 19607386, 5943299, -18344588, 37462663], [3829400469, 129190004, -92269003, 964091, 7415314, -3964801, -7042879], [-105307493963, -132531012, 39292300, -14043938, -14499612, -304203, 8162121], [82489905068, -17509787, 120003374, -11668376, 13963790, 3155936, -19600498], [111704885070, -53556771, 69706592, -25762989, -2142051, -38560368, 36693600], [-43628476759, -279052456, 25915379, 25943756, -4449111, 10683216, 1436615], [-125556738714, -294969534, -122028348, 1871085, 21583500, 34013036, -16832398], [-16615714718, 133278223, -72036006, 37999569, -3324879, -18731580, 18949806], [-48608407789, 319373826, 130378844, -29942074, -6035814, -50647128, 41390640], [57119170374, 7156018, -85197328, -8910443, -39706252, 20015002, 25061830], [-2243036492, -94677558, -87535016, 13239463, 26219637, -27158952, -3816864], [36950709774, -542873612, 91783180, -22490033, -33352519, 2443376, -15604492], [137051125134, -85812292, -17428968, -20542318, 13350508, -24248666, 15310750], [-128954712219, -677665268, 110172710, 7104598, -2800348, -34686584, -10667234], [-94900474354, 648914008, 129832895, 1571842, 6425540, 26593172, -36777706], [93884473875, 103146267, 221960166, 1018713, 2584527, 3921530, -5826160], [-121790423140, 36839824, 144717920, 59245096, 18220424, -40491112, 42418484], [-139473269807, 396338774, -8960454, -10075089, 22143804, -54010644, 7622059], [106215348528, -388157570, 134152724, -18018893, 7251689, -27695300, 47844064], [124404452058, -9116118, -244238877, -13572108, 6581277, 54762584, -27377965], [-170646792978, 195222178, -55435634, 12970105, 34949280, -33931902, -3380554], [49218002174, -37044904, 53018107, 49486174, 11271156, -9134772, -38814362], [73656873108, 361500628, 75381119, 30447784, 43722476, -28252010, 23856016], [30308122395, 451752188, -5962643, 21344287, -31571442, 27836511, -65240781], [-85212335224, 649688465, -14477696, -20311888, 10623496, -24708872, 42445552], [-115735944469, 19066288, -75669478, -16843058, 14021108, 55524077, -69608437], [-24087618703, 176916120, 17394074, -4606393, -24653394, 4258983, 19814517], [-9687529512, 221357799, -69116564, -4343769, -30814101, 57399046, -66093386], [-98075373804, -283774787, -27157486, -12882508, -22696722, 8895480, -98326746], [19882210820, 405910376, -270032573, 39484370, -27388244, -9940130, 25443916], [-88322019560, 247453047, 180083067, -7533891, -16090314, -16821966, 2852849], [-139205305772, 177842928, 67373786, -5163115, -12671643, 52880976, 9469054], [-161285494531, 479612348, 243070380, -32471388, -26004852, 2686686, 17335659], [-48998498187, -119883824, 173746966, 29454994, 22280736, 20439816, -30672394], [-155496585794, 417776070, -192116654, 32255203, 23005656, -41000850, 23885646], [-43268437834, -25743885, 2488200, 22451700, 8902320, -109176900, 74396604], [-53609435282, 824880727, -123853950, 3338388, -12240846, 4302924, -54508758], [102460153545, 188306304, 294550933, -44988735, 10688358, 31183861, 6320845], [17718981988, 523505572, 32090120, 5371253, 26370147, 36071760, -47621716], [-128684995366, -69267828, -109896418, 13182134, 10580688, 45254472, 25690062], [24288792195, 275541846, -184593614, -24700071, 23001816, 80005744, -34729031], [69082976307, -323570356, 356699966, -31003384, -36417146, -20075056, 22996490], [-141941974878, -556375131, -198029252, -37249949, 23464689, 12587880, 32583256], [-103015372596, 151254532, -25610488, -49281356, 22539008, -19889348, -12812048], [-10290978225, -32077390, 170000036, -55054555, -54457140, 62704764, -7952147], [89397212433, 383975118, 171992246, -41584005, 21347316, -19820388, -31564245], [111572906028, 157427507, 63316732, 29216183, 22000927, 112139946, -92882790], [-105222387634, -544080292, 78012428, 8310542, 32858508, -2860197, -21926344], [-141891042244, -435972589, -294653210, 10807754, 7917304, -7391480, -49416146], [161250694792, -89552192, -66779079, 54279480, 13650120, -36503352, 89569476], [-20538042654, 595541791, -52399602, 40847749, -15041959, -30689820, 29122974], [332182611494, -160491436, -17012959, -27318904, -4888356, -29751990, -54113062], [-30980530598, 35287119, -397832334, 15433989, 27452145, 3724872, -14239426], [-99903959279, 122782749, 51789537, 24719727, -21751746, -70789086, 41895767], [-99199306182, -758294600, 212726916, 31374370, -3087280, -85848843, 20920560], [232434615608, -703163804, 154665582, -28249596, -25176084, 440058, -71356456], [-68358114372, -535395788, -54915415, -55618292, 4628459, 91784944, -6872123], [24271398610, -120052474, -119463812, 48892093, 14555640, -92313048, -36320266], [273810219475, 880352728, 11601767, 44910353, 53712822, -22762383, 17535731], [126262934781, 218468286, -54532854, 58433544, 36543906, 45118088, -72102922], [10088709477, -73850364, -424584649, 45250892, 47281485, 113225160, -59336485], [-100680145774, -799317698, 53080034, 91507375, 7601696, 21972296, -75424162], [-85884367503, 189861642, -97416344, -3724992, 7823232, -80409848, 12042208], [-73279989656, -54156871, 51712080, 35467041, -35113449, 75351300, -10573004], [3146169480, 97494628, 126661598, 10433062, 31158188, 68001424, -75179768], [49051222175, -1496889644, 288080477, 18727274, -50229219, -36362364, 70336717], [-1830596628, 476076709, -155020679, -53147441, 10288730, -14970898, 74088659], [74236882805, 2658092, 285634036, 28732796, 11509804, -20899730, 78412819], [38702307284, 270712698, -40054002, -67224963, 77383308, 39089874, 7244688], [381876270714, 363093036, 105601309, 45110104, 79441116, 3059262, -4593146], [218127728594, 990783689, 125202112, -19040789, 31239969, -121364676, 57897676], [58610965586, 572318935, 52202384, -31865468, -66271612, 85863176, 34037120], [45745837690, 606764125, 141109808, -46749010, 11602470, 9557760, -35892916], [-38235886470, 404656904, 82582407, -74170948, -81963392, -80060, 62622478], [179094258445, 43091436, 297627782, -65956006, -33019104, -27178773, 59455837], [50461377092, 414509318, 20902228, 20715221, 26414188, 1219567, -114588998], [-20768782154, -1021755376, 196126018, 104493046, 6138084, -39917016, 62637602], [78597089744, 142556640, -268068534, 12237558, 46662672, 37108644, -90393690], [235681206599, 1120469807, 137983198, 3542593, -29933733, -36422130, 28864012], [-17980990689, -378525279, -241270998, -43959405, -40741719, 59032430, -88309564], [55935655751, 143220924, 79171110, 61151751, -49015926, -34200837, -24505137], [54461833722, 800449864, 13840080, -810329, -66735031, -38883804, 83834472], [-16083097183, 759694631, -287521879, -7156471, 27758136, 19615890, 121225907], [-38751420200, -830915211, 70261342, 53873632, -9082350, -109985172, 89124486], [69275861592, -182985780, -28617241, 17448162, 98734944, -177014730, 67287264], [257206319332, 1403081650, 161498344, 41700415, 37083705, 57338580, -89158520], [63660323153, -246391444, -278950164, 95929032, -3031524, -234816126, 51100839], [-51552640366, 504139283, 360041038, 38086301, 23523829, -80317664, -61157594], [13753843635, -38700816, -468374142, 73813476, 38474484, -134813143, 94450043], [327461234901, -547289084, 7011571, 34149727, -51765630, 164926605, -86490055], [-82170085982, 654313256, 368919580, 45342424, -1133664, 92405508, 16179428], [-80891900394, -111249692, -640685672, 77322886, 64386164, 18816881, -97725844], [96320359476, -1251283906, 71812283, 95573486, -18737201, 38722256, -53533033], [-112313280276, -264615320, 229098052, 63142621, 34085271, -8390784, -149343712], [-151606534051, -278310256, -156106193, -17424589, 16555234, -226819955, 131160181], [-25139904286, 614305658, 314540884, -830371, 3402463, 3011848, -64732316], [71769911716, -1445219356, -455719358, -25783034, -21340536, 71277780, 51782954], [459651789287, 326456808, -118361487, -66709599, -17001066, -23435049, -87747329], [-310630629070, -662612036, -300679374, -49256586, -68582976, -192911772, 177754310], [-134576162999, 643629145, -27161175, -113020005, 56691810, -34975758, 46572399], [674133127795, 1248345464, 181415155, -19361789, 15794634, -22332639, 158521259], [-88602489894, -525775990, 343457606, 6013565, 59914045, -160434316, -11030398], [-256355994235, -409301872, 98284026, -16343430, 21890988, 73445520, -243214182], [371921503923, 710679804, 136805430, -137253849, -44420886, -158152797, 55954611], [-181339841688, 361039234, -212295130, -7087609, -130871736, 125935572, 1746168], [47960227128, 257833886, 245708534, 15445799, -67937084, 177833435, -49382650], [-142940514867, -787848777, 458278484, -134243253, -45194697, 133297842, 166782], [-231018159594, -1262994902, 52915592, 79099757, 92493063, -135971316, -7575372], [-179393114523, -939891012, 276611038, -85368813, 42646218, 111297667, 21732625], [36916120902, -1259515944, -398991731, 154872486, 63725877, -34893164, -85577711], [-331368558992, 2884997300, -180092926, -80564548, 949392, -58249293, 5222526], [144741810804, 1392014106, -19456090, -73326411, 59269860, -60559491, 24755118], [436848290138, -1427389924, 168158543, 24929204, -37615164, 21606954, 6949862], [-314731861874, -282825044, 553058940, -99534021, -72034515, -114346536, 216893028], [-70025268012, 387443540, 92146703, 121033724, -78872, -80289250, 9244868], [-500332502334, -1699657979, 311169024, -52620641, -5117239, 73100496, 142763952], [-435210925264, 1492192386, 465031614, 134477001, 25896588, 157071360, -22212392], [8981521331, 434931948, -301046798, -59847827, -48937110, -189248391, 142137563], [357981618846, 688410093, 626082622, -18964113, -96580587, 78117838, -32306252], [-336391786114, -279860744, 177017961, -63253578, -23595459, 252299184, -174061111], [293480449379, -981137336, -289379035, 64539946, 14588369, 236686664, -148950895], [-549102302366, 1155061637, 997369478, -35204998, -11572920, -1003464, -57339138], [-2795540795, -1513850102, -128471500, 96774812, -24481932, 142347804, -157813192], [141233815908, 30531144, -136456582, 35692536, -42828096, 391863630, -137457060], [-315355824043, 1082824729, -811886708, 198672661, -31166271, -105892878, 83475018], [-41439004623, 1200534224, -2076946, 156592898, 70092712, -236554207, 46001453], [312459770424, -2647046120, 160255652, 108869060, 25158240, 60414360, -233909928], [278237901998, 1028690948, 123272689, 112948934, 99674896, -64759280, 151745806], [200718868770, -552353517, -338710492, -45705348, 20669868, -193236372, 300372192], [225220163502, 2414049220, 123277896, -73476650, -35731060, -87891342, 99049566], [-20130144190, 489049656, 168543011, -41155516, -18605484, 15113214, 84656394], [-68483068737, 371365015, 35709218, 138660049, -115709653, -112077254, -62648276], [92817632596, 1345086646, -624231938, 55903399, -91159689, -103123212, -25967114], [-569773920797, 808818724, 632016252, -87168348, 41677884, -201387606, 97249437], [-386333141727, 2010848960, 23009484, -51304900, -32449460, 261875335, -285049871], [-326939732084, -3114380136, -9181213, 72644612, 74545188, -79518180, -180357212], [-273196443001, 379361820, -410546103, -100398030, -57771615, 87255420, 48445017], [-226525546455, 861561936, -171215770, 7291629, -36699786, 159043605, -272469531], [-311749534159, -318414939, -358495462, 34622213, 122114151, -95575854, -107426292], [636123429075, 518714020, -218036590, -45255260, 10829468, 261883087, -59619713], [-516579260848, 659213876, 263552774, 89455361, -10354371, 25798944, -122840518], [-80437635768, 384681681, 40374612, -80980020, 165130632, -267750976, 62963180], [127075816790, 1458039556, -551875235, 47575474, -131902659, 117356640, 114451221], [-299907765021, -1937309152, -371979737, 33802577, 9847918, 5573169, 23443803], [-349982195689, 1825659576, -305393911, 298843694, 89444241, -88351152, 44760957], [-310415082270, 768431136, -529974836, 122747536, 17488680, -201989772, -114143804], [91112317413, -306056780, 828808994, -110475263, -81274102, -245948759, 253450465], [-96432085890, -746222823, -793346330, -78426702, -18107028, -150941732, -126331478], [-597821511869, -1907075686, -287819422, 52801190, 64999404, 379180740, -10301706], [-545213892148, 327225154, 810958184, 61686721, -68835016, -106506238, 74449304], [-630731769553, 1383460390, 1115329566, -9553827, -51749088, -66775056, -155904955], [458570076333, -2036719947, -75720084, 108523977, -74249007, -15378154, 221264798], [-512049194402, -1614463429, -57308738, -174408056, -205373994, -56060472, 174267494], [-37900340809, 1960452944, 689086412, 30355946, 15228084, -385486212, 203466029], [181095728918, -568176442, -604694060, -45044743, 75165880, 193766212, 110874634], [-319037818179, -1741535982, 662048963, 75225762, 296343, 194253312, 289349211], [-394939833704, 2680149331, -15540518, 22379875, 34427823, -28968792, 206896354], [-72157169104, -2064952360, 845013226, 221544418, -119598240, -179844204, 256616992], [445627249215, -2097623836, -31531855, 1803611, -45044966, -42783805, -154760101], [-166190107772, -1327010014, 672683207, -191045086, 16557831, -105015816, 97496019], [766351146016, 3904710500, 828107901, -16592250, 34834020, -254397822, 396985612], [-5383994022, -676229209, 326963540, 207386564, 127476744, -143330760, 346800484], [823740749076, 1880992281, 180459636, -23156151, 151288251, 198660908, -121542412], [-104473318730, -2520552944, -35735109, -75211836, -78279624, 162282864, 263958954], [-452241794653, 1656715236, 926955600, 41216934, -26890212, -138131049, -110478785], [98049391284, -2474390869, -1133197052, 41121599, 34903111, -199272462, -66799014], [-102383267386, -740544032, -330490564, -184917253, 13571493, 496060056, -324995588], [-53579549379, -1604952712, -486508350, 185423202, 195470508, -281354013, -55515163], [164903305696, -997621461, 728113244, -134606557, 46483287, -268499442, 121429678], [406350033542, -811628616, 77058858, 144874230, -10891860, -231045096, -140099502], [98519567303, -194885072, 417307157, 135588233, 123250650, -185860671, 242491063]]
